from ..base import AdyenServiceBase
from .api_credentials_company_level_api import APICredentialsCompanyLevelApi
from .api_credentials_merchant_level_api import APICredentialsMerchantLevelApi
from .api_key_company_level_api import APIKeyCompanyLevelApi
from .api_key_merchant_level_api import APIKeyMerchantLevelApi
from .account_company_level_api import AccountCompanyLevelApi
from .account_merchant_level_api import AccountMerchantLevelApi
from .account_store_level_api import AccountStoreLevelApi
from .allowed_origins_company_level_api import AllowedOriginsCompanyLevelApi
from .allowed_origins_merchant_level_api import AllowedOriginsMerchantLevelApi
from .android_files_company_level_api import AndroidFilesCompanyLevelApi
from .client_key_company_level_api import ClientKeyCompanyLevelApi
from .client_key_merchant_level_api import ClientKeyMerchantLevelApi
from .my_api_credential_api import MyAPICredentialApi
from .payment_methods_merchant_level_api import PaymentMethodsMerchantLevelApi
from .payout_settings_merchant_level_api import PayoutSettingsMerchantLevelApi
from .split_configuration_merchant_level_api import SplitConfigurationMerchantLevelApi
from .terminal_actions_company_level_api import TerminalActionsCompanyLevelApi
from .terminal_actions_terminal_level_api import TerminalActionsTerminalLevelApi
from .terminal_orders_company_level_api import TerminalOrdersCompanyLevelApi
from .terminal_orders_merchant_level_api import TerminalOrdersMerchantLevelApi
from .terminal_settings_company_level_api import TerminalSettingsCompanyLevelApi
from .terminal_settings_merchant_level_api import TerminalSettingsMerchantLevelApi
from .terminal_settings_store_level_api import TerminalSettingsStoreLevelApi
from .terminal_settings_terminal_level_api import TerminalSettingsTerminalLevelApi
from .terminals_terminal_level_api import TerminalsTerminalLevelApi
from .users_company_level_api import UsersCompanyLevelApi
from .users_merchant_level_api import UsersMerchantLevelApi
from .webhooks_company_level_api import WebhooksCompanyLevelApi
from .webhooks_merchant_level_api import WebhooksMerchantLevelApi


class AdyenManagementApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AdyenManagementApi, self).__init__(client=client)
        self.api_credentials_company_level_api = APICredentialsCompanyLevelApi(client=client)
        self.api_credentials_merchant_level_api = APICredentialsMerchantLevelApi(client=client)
        self.api_key_company_level_api = APIKeyCompanyLevelApi(client=client)
        self.api_key_merchant_level_api = APIKeyMerchantLevelApi(client=client)
        self.account_company_level_api = AccountCompanyLevelApi(client=client)
        self.account_merchant_level_api = AccountMerchantLevelApi(client=client)
        self.account_store_level_api = AccountStoreLevelApi(client=client)
        self.allowed_origins_company_level_api = AllowedOriginsCompanyLevelApi(client=client)
        self.allowed_origins_merchant_level_api = AllowedOriginsMerchantLevelApi(client=client)
        self.android_files_company_level_api = AndroidFilesCompanyLevelApi(client=client)
        self.client_key_company_level_api = ClientKeyCompanyLevelApi(client=client)
        self.client_key_merchant_level_api = ClientKeyMerchantLevelApi(client=client)
        self.my_api_credential_api = MyAPICredentialApi(client=client)
        self.payment_methods_merchant_level_api = PaymentMethodsMerchantLevelApi(client=client)
        self.payout_settings_merchant_level_api = PayoutSettingsMerchantLevelApi(client=client)
        self.split_configuration_merchant_level_api = SplitConfigurationMerchantLevelApi(client=client)
        self.terminal_actions_company_level_api = TerminalActionsCompanyLevelApi(client=client)
        self.terminal_actions_terminal_level_api = TerminalActionsTerminalLevelApi(client=client)
        self.terminal_orders_company_level_api = TerminalOrdersCompanyLevelApi(client=client)
        self.terminal_orders_merchant_level_api = TerminalOrdersMerchantLevelApi(client=client)
        self.terminal_settings_company_level_api = TerminalSettingsCompanyLevelApi(client=client)
        self.terminal_settings_merchant_level_api = TerminalSettingsMerchantLevelApi(client=client)
        self.terminal_settings_store_level_api = TerminalSettingsStoreLevelApi(client=client)
        self.terminal_settings_terminal_level_api = TerminalSettingsTerminalLevelApi(client=client)
        self.terminals_terminal_level_api = TerminalsTerminalLevelApi(client=client)
        self.users_company_level_api = UsersCompanyLevelApi(client=client)
        self.users_merchant_level_api = UsersMerchantLevelApi(client=client)
        self.webhooks_company_level_api = WebhooksCompanyLevelApi(client=client)
        self.webhooks_merchant_level_api = WebhooksMerchantLevelApi(client=client)
