from ..base import AdyenServiceBase
from .business_lines_api import BusinessLinesApi
from .documents_api import DocumentsApi
from .hosted_onboarding_api import HostedOnboardingApi
from .legal_entities_api import LegalEntitiesApi
from .pci_questionnaires_api import PCIQuestionnairesApi
from .terms_of_service_api import TermsOfServiceApi
from .transfer_instruments_api import TransferInstrumentsApi


class AdyenLegalEntityManagementApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AdyenLegalEntityManagementApi, self).__init__(client=client)
        self.business_lines_api = BusinessLinesApi(client=client)
        self.documents_api = DocumentsApi(client=client)
        self.hosted_onboarding_api = HostedOnboardingApi(client=client)
        self.legal_entities_api = LegalEntitiesApi(client=client)
        self.pci_questionnaires_api = PCIQuestionnairesApi(client=client)
        self.terms_of_service_api = TermsOfServiceApi(client=client)
        self.transfer_instruments_api = TransferInstrumentsApi(client=client)
