from ..base import AdyenServiceBase
from .capital_api import CapitalApi
from .transactions_api import TransactionsApi
from .transfers_api import TransfersApi


class AdyenTransfersApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AdyenTransfersApi, self).__init__(client=client)
        self.capital_api = CapitalApi(client=client)
        self.transactions_api = TransactionsApi(client=client)
        self.transfers_api = TransfersApi(client=client)
