from ..base import AdyenServiceBase
from .modifications_api import ModificationsApi
from .payments_api import PaymentsApi


class AdyenPaymentsApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AdyenPaymentsApi, self).__init__(client=client)
        self.modifications_api = ModificationsApi(client=client)
        self.payments_api = PaymentsApi(client=client)
