from ..base import AdyenServiceBase


class TransferRoutesApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(TransferRoutesApi, self).__init__(client=client)
        self.service = "balancePlatform"
        self.baseUrl = "https://balanceplatform-api-test.adyen.com/bcl/v2"

    def calculate_transfer_routes(self, request, idempotency_key=None, **kwargs):
        """
        Calculate transfer routes
        """
        endpoint = self.baseUrl + f"/transferRoutes/calculate"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

