from ..base import AdyenServiceBase
from .initialization_api import InitializationApi
from .instant_payouts_api import InstantPayoutsApi
from .reviewing_api import ReviewingApi


class AdyenPayoutsApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AdyenPayoutsApi, self).__init__(client=client)
        self.initialization_api = InitializationApi(client=client)
        self.instant_payouts_api = InstantPayoutsApi(client=client)
        self.reviewing_api = ReviewingApi(client=client)
